@@ -1,3 +1,6 @@
+from opentelemetry import trace
+from opentelemetry.semconv._incubating.attributes.user_attributes import USER_ID
+
 from plain import auth
 from plain.exceptions import ImproperlyConfigured
 from plain.utils.functional import SimpleLazyObject
@@ -6,6 +9,8 @@ from plain.utils.functional import SimpleLazyObject
 def get_user(request):
     if not hasattr(request, "_cached_user"):
         request._cached_user = auth.get_user(request)
+        if request._cached_user:
+            trace.get_current_span().set_attribute(USER_ID, request._cached_user.id)
     return request._cached_user
 
 
@@ -22,6 +27,7 @@ class AuthenticationMiddleware:
                 "'plain.sessions.middleware.SessionMiddleware' before "
                 "'plain.auth.middleware.AuthenticationMiddleware'."
             )
+
         request.user = SimpleLazyObject(lambda: get_user(request))
-        response = self.get_response(request)
-        return response
+
+        return self.get_response(request)
